@@ -13,10 +13,12 @@
 #include <stdlib.h>
 #include <fcntl.h>
 #include <unistd.h>
+#ifndef NO_RPC
 #include <rpc/rpc.h>
 #ifdef HAVE_RPCENT_H
 #include <rpc/rpcent.h>
 #endif
+#endif
 #include <netdb.h>
 
 #include "str.h"
@@ -730,7 +732,7 @@ static status_e check_entry( struct service_config *scp,
 	   }
    }
 
-/* #ifndef NO_RPC */
+#ifndef NO_RPC
    if ( SC_IS_RPC( scp ) && !SC_IS_UNLISTED( scp ) )
    {
       struct rpcent *rep = (struct rpcent *)getrpcbyname( SC_NAME(scp) ) ;
@@ -743,6 +745,7 @@ static status_e check_entry( struct service_config *scp,
       SC_RPCDATA( scp )->rd_program_number = rep->r_number ;
    }
    else
+#endif
    {
        if ( !SC_IS_UNLISTED( scp ) ) 
        { 
@@ -843,6 +846,14 @@ static status_e check_entry( struct service_config *scp,
       }
    }
 
+   if ( SC_SOCKET_TYPE(scp) == SOCK_DGRAM && !SC_WAITS(scp) )
+   {
+         msg( LOG_ERR, func,
+              "Service %s has socket_type dgram, but does not wait",
+              SC_NAME(scp) );
+         return FAILED;
+   }
+
    if ( service_attr_check( scp ) == FAILED )
       return( FAILED ) ;
 
